import requests
import time


def get_create_time(cls):
    creat_time = int(round(time.time() * 1000))
    return creat_time


class CrawlAPI(object):
    def add(self, a, b):
        return a + b

    @classmethod
    def sub(cls, a, b):
        return a - b



import setuptools

with open("README.md", "r",encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="zzu_low2",  # Replace with your own username
    version="0.4",
    author="CooperHan",
    author_email="wy2208293418@163.com",
    description="A sample Crawler API",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/TomersHan/AI-X-crawler",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",

    ],
    python_requires='>=3.6',
)
